Learn R Programming

farsi (version 1.0)

as.character.farsi: Integers into persian

Description

Translates integer vectors into character strings representing their expression in the persianlanguage.

Usage

"as.character"(x, ...)

Arguments

x
A numeric vector of class farsi.
...
Currently unused.

Value

A character string vector

Details

Uses a recursive algorithm to translate numbers into their expression in farsi.

References

See original note by Sadegh Rasoulinejad at

See Also

farsi, as.farsi, print.farsi.

Examples

Run this code
as.character(farsi(10001001 + 1:10))

Run the code above in your browser using DataLab