Learn R Programming

farsi (version 1.0)

print.farsi: A print method for objects of cleas persian

Description

Provides a print method for objects of class farsi.

Usage

"print"(x, ...)

Arguments

x
An object of class farsi
...
Additional arguments to be passed to the print generic function.

Value

The original object, invisibly.

Details

Coerces the object to character and prints it.

References

See original note by Sadegh Rasoulinejad at

See Also

as.character.farsi.

Examples

Run this code
print(farsi(1:10))

Run the code above in your browser using DataLab