|
Package: |
| farsi |
|
Type: |
| Package |
|
Version: |
| 1.0-1 |
|
Date: |
| 2013-03-08 |
|
License: |
| GPL-2 |
|
LazyLoad: |
| yes |
In answer to a question on R-help Sadegh Rasoulinejad provided an elegant R
function to translate integers into persian numbers. The present
package extends this code to an S3 class, with constructor functions and
methods to make this original idea more conveniently available.The function as.farsi is intended to provide a parallel
facility to the function as.roman in the utils package.
The main purpose of the package is to present an interesting programming
example rather than to solve a likely real problem, though there could
well be some applications in unusual contexts.